EXEC [__AddStoredProcInfo]
	/* StoredProc_Name         */ 'Packages_GetFeedSyncPackages',
	/* Internal_Indicator      */ 'Y',
	/* ReturnType_Name         */ 'DataTable',
	/* DataTableNames_Csv      */ 'Packages_FeedSync',
	/* OutputPropertyNames_Csv */ NULL,
	/* Description_Text        */ 'Gets the feed sync packages.'
GO

IF OBJECT_ID('[Packages_GetFeedSyncPackages]') IS NOT NULL DROP PROCEDURE [Packages_GetFeedSyncPackages]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Packages_GetFeedSyncPackages]
(
	@Feed_Id INT,
	@Since_Date DATETIME = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	DECLARE @FeedType_Name VARCHAR(20)
	SELECT @FeedType_Name = [FeedType_Name]
	  FROM [Feeds]
	 WHERE [Feed_Id] = @Feed_Id

	IF @FeedType_Name IS NULL
	    RAISERROR('Invalid feed.', 16, 1)

	ELSE IF @FeedType_Name IN ('NuGet', 'Chocolatey', 'Deployment', 'PowerShell')

	    SELECT NP.[Feed_Id],
	           [Group_Name] = NULL,
	           [Package_Name] = NP.[Package_Id],
	           NPV.[Version_Text],
	           [File_Type] = NULL,
	           [Updated_Date] = NPV.[Published_Date],
	           [Package_Hash] = NPV.[PackageHash_SHA512_Bytes]
	      FROM [NuGetPackageVersionsV2] NPV
	           INNER JOIN [NuGetPackagesV2] NP
	                   ON NP.[NuGetPackageV2_Id] = NPV.[NuGetPackageV2_Id]
	     WHERE NP.[Feed_Id] = @Feed_Id
	       AND NPV.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR NPV.[Published_Date] >= @Since_Date)

	  UNION ALL

	    SELECT NP.[Feed_Id],
	           [Group_Name] = NULL,
	           [Package_Name] = NP.[Package_Id],
	           NP.[Version_Text],
	           [File_Type] = NULL,
	           [Updated_Date] = NP.[Published_Date],
	           [Package_Hash] = NP.[PackageHash_Bytes]
	      FROM [NuGetPackages] NP
	     WHERE NP.[Feed_Id] = @Feed_Id
	       AND NP.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR NP.[Published_Date] >= @Since_Date)
	  ORDER BY [Feed_Id], [Package_Id]

	ELSE IF @FeedType_Name = 'npm'

	    SELECT NP.[Feed_Id],
	           [Group_Name] = NP.[Scope_Name],
	           NP.[Package_Name],
	           NPV.[Version_Text],
	           [File_Type] = NULL,
	           [Updated_Date] = NPV.[Published_Date],
	           [Package_Hash] = NPV.[PackageHash_Bytes]
	      FROM [NpmPackages] NP
	           INNER JOIN [NpmPackageVersions] NPV
	                   ON NPV.[Package_Id] = NP.[Package_Id]
	     WHERE NP.[Feed_Id] = @Feed_Id
	       AND NPV.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR NPV.[Published_Date] >= @Since_Date)
	  ORDER BY NP.[Package_Id]

	ELSE IF @FeedType_Name = 'Bower'

	    SELECT BP.[Feed_Id],
	           [Group_Name] = NULL,
	           BP.[Package_Name],
	           [Version_Text] = NULL,
	           [File_Type] = NULL,
	           [Updated_Date] = NULL,
	           [Package_Hash] = NULL
	      FROM [BowerPackages] BP
	     WHERE BP.[Feed_Id] = @Feed_Id

	ELSE IF @FeedType_Name = 'Maven'

	    SELECT MA.[Feed_Id],
	           [Group_Name] = MA.[GroupId_Text],
	           [Package_Name] = MA.[ArtifactId_Text],
	           MAF.[Version_Text],
	           MAF.[File_Type],
	           MAF.[Updated_Date],
	           [Package_Hash] = MAF.[File_SHA1_Bytes]
	      FROM [MavenArtifacts] MA
	           INNER JOIN [MavenArtifactFiles] MAF
	                   ON MAF.[MavenArtifact_Id] = MA.[MavenArtifact_Id]
	     WHERE MA.[Feed_Id] = @Feed_Id
	       AND MAF.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR MAF.[Updated_Date] >= @Since_Date)
	  ORDER BY MA.[MavenArtifact_Id]

	ELSE IF @FeedType_Name = 'ProGet'

	    SELECT PGP.[Feed_Id],
	           PGP.[Group_Name],
	           PGP.[Package_Name],
	           PGPV.[Version_Text],
	           [File_Type] = NULL,
	           [Updated_Date] = PGPV.[Published_Date],
	           [Package_Hash] = PGPV.[PackageHash_Bytes]
	      FROM [ProGetPackages] PGP
	           INNER JOIN [ProGetPackageVersions] PGPV
	                   ON PGPV.[ProGetPackage_Id] = PGP.[ProGetPackage_Id]
	     WHERE PGP.[Feed_Id] = @Feed_Id
	       AND PGPV.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR PGPV.[Published_Date] >= @Since_Date)
	  ORDER BY PGP.[ProGetPackage_Id]

	ELSE IF @FeedType_Name = 'VSIX'

	    SELECT P.[Feed_Id],
	           [Group_Name] = NULL,
	           [Package_Name] = P.[Package_Id],
	           [Version_Text] = CAST(P.[Major_Number] AS VARCHAR(50)) + '.' + CAST(P.[Minor_Number] AS VARCHAR(50)) + '.' + CAST(P.[Build_Number] AS VARCHAR(50)) + '.' + CAST(P.[Revision_Number] AS VARCHAR(50)),
	           [File_Type] = NULL,
	           [Updated_Date] = P.[Published_Date],
	           [Package_Hash] = P.[PackageHash_Bytes]
	      FROM [VsixPackages] P
	     WHERE P.[Feed_Id] = @Feed_Id
	       AND P.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR P.[Published_Date] >= @Since_Date)
	  ORDER BY P.[Package_Id]

	ELSE IF @FeedType_Name = 'RubyGems'

	    SELECT G.[Feed_Id],
	           [Group_Name] = NULL,
	           [Package_Name] = G.[Gem_Name],
	           [Version_Text] = GV.[Version_Text],
	           [File_Type] = GV.[Platform_Text],
	           [Updated_Date] = GV.[Published_Date],
	           [Package_Hash] = GV.[GemHash_Bytes]
	      FROM [RubyGems] G
	           INNER JOIN [RubyGemVersions] GV
	                   ON G.[Gem_Id] = GV.[Gem_Id]
	     WHERE G.[Feed_Id] = @Feed_Id
	       AND GV.[Cached_Indicator] = 'N'
	       AND (@Since_Date IS NULL OR GV.[Published_Date] >= @Since_Date)
	  ORDER BY G.[Gem_Id]

	ELSE
	    RAISERROR('Invalid feed type.', 16, 1)

END
GO

GRANT EXECUTE ON [Packages_GetFeedSyncPackages] TO [ProGetUser_Role]
GO