EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'ProGetPackages_IncrementDownloadCount',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Increments the download count for a ProGet package.'
GO

IF OBJECT_ID('[ProGetPackages_IncrementDownloadCount]') IS NOT NULL DROP PROCEDURE [ProGetPackages_IncrementDownloadCount]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ProGetPackages_IncrementDownloadCount]
(
	@Feed_Id INT,
	@Group_Name NVARCHAR(200),
	@Package_Name NVARCHAR(100),
	@Version_Text NVARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @ProGetPackage_Id INT
		SET @ProGetPackage_Id = (SELECT [ProGetPackage_Id] FROM [ProGetPackages] WHERE [Feed_Id] = @Feed_Id AND [Group_Name] = @Group_Name AND [Package_Name] = @Package_Name)

		UPDATE [ProGetPackageVersions]
		   SET [Download_Count] = [Download_Count] + 1
		 WHERE [ProGetPackage_Id] = @ProGetPackage_Id
		   AND [Version_Text] = @Version_Text

		DECLARE @Total_Download_Count INT
		SET @Total_Download_Count = COALESCE((SELECT SUM([Download_Count])
		                                        FROM [ProGetPackageVersions]
									           WHERE [ProGetPackage_Id] = @ProGetPackage_Id), 0)

		UPDATE [ProGetPackages]
		   SET [Download_Count] = @Total_Download_Count
		 WHERE [ProGetPackage_Id] = @ProGetPackage_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [ProGetPackages_IncrementDownloadCount] TO [ProGetUser_Role]
GO